@@ -1,13 +1,5 @@
-#!/usr/bin/env python3
-# --------------------------------------------------------------------------------------
 # SPDX-FileCopyrightText: 2021 Magenta ApS <https://magenta.dk>
 # SPDX-License-Identifier: MPL-2.0
-# --------------------------------------------------------------------------------------
-# --------------------------------------------------------------------------------------
-# Imports
-# --------------------------------------------------------------------------------------
-from typing import List
-from typing import Optional
 from uuid import UUID
 
 from pydantic import Field
@@ -19,10 +11,6 @@ from .._shared import OrgUnitRef
 from .._shared import Validity
 from ._shared import Details
 
-# --------------------------------------------------------------------------------------
-# KLE models
-# --------------------------------------------------------------------------------------
-
 
 class KLEBase(MOBase):
     """A MO KLE object.
@@ -39,8 +27,8 @@ class KLERead(KLEBase):
     """A MO KLERead object."""
 
     kle_number_uuid: UUID = Field(description="UUID of the KLE number.")
-    kle_aspect_uuids: List[UUID] = Field(description="List of UUIDs of the KLE aspect.")
-    org_unit_uuid: Optional[UUID] = Field(
+    kle_aspect_uuids: list[UUID] = Field(description="List of UUIDs of the KLE aspect.")
+    org_unit_uuid: UUID | None = Field(
         description="UUID of the organisation unit related to the KLE."
     )
 
@@ -49,10 +37,10 @@ class KLEWrite(KLEBase):
     """A MO KLEWrite object."""
 
     kle_number: KLENumberRef = Field(description="Reference to the KLE number klasse.")
-    kle_aspects: List[KLEAspectRef] = Field(
+    kle_aspects: list[KLEAspectRef] = Field(
         description="List of references to the KLE aspect klasse."
     )
-    org_unit: Optional[OrgUnitRef] = Field(
+    org_unit: OrgUnitRef | None = Field(
         description="Reference to the organisation unit for the KLE."
     )
 
@@ -65,9 +53,9 @@ class KLE(KLEBase):
     """Service API-compatible model with singular `kle_aspect`."""
 
     kle_number: KLENumberRef = Field(description="Reference to the KLE number klasse.")
-    kle_aspect: List[KLEAspectRef] = Field(
+    kle_aspect: list[KLEAspectRef] = Field(
         description="List of references to the KLE aspect klasse."
     )
-    org_unit: Optional[OrgUnitRef] = Field(
+    org_unit: OrgUnitRef | None = Field(
         description="Reference to the organisation unit for the KLE."
     )
